.. Copyright (C) 2019 Leonardo Bechea <leonardo.bechea@innobyte.com>
.. Copyright (C) 2019 Alin Alexandru <alin.alexandru@innobyte.com>
.. Copyright (C) 2019 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.tinyproxy`` role can be used to install Tinyproxy on a Debian or
Ubuntu host. Tinyproxy is a light-weight HTTP/HTTPS proxy daemon for POSIX operating systems.
